@@ -35,26 +35,17 @@ public:
     BluezQt::DevicePtr device() const;
     void setDevice(BluezQt::DevicePtr device);
 
-    QString pin() const;
-    void setPin(const QString &pin);
-
     WizardAgent *agent() const;
     BluezQt::Manager *manager() const;
 
     enum {
         Discover,
-        LegacyPairing,
-        LegacyPairingDatabase,
-        KeyboardPairing,
-        SSPPairing,
+        Pairing,
         Success,
         Fail,
         Connect
     };
 
-public Q_SLOTS:
-    void restartWizard();
-
 private Q_SLOTS:
     void initJobResult(BluezQt::InitManagerJob *job);
     void operationalChanged(bool operational);
@@ -66,7 +57,6 @@ private:
     WizardAgent *m_agent;
 
     BluezQt::DevicePtr m_device;
-    QString m_pin;
 };
 
 #endif // BLUEWIZARD_H
